country_and_time = {
    "afghanistan": "4:30",
    "albania": "2:00",
    "algeria": "1:00",
    "andorra": "2:00",
    "angola": "1:00",
    "antigua and barbuda": "-4:00",
    "argentina": "-3:00",
    "armenian": "4:00",
    "australian western standard time": "8:00",
    "australian central western standard time": "8:45",
    "australian central standard time": "9:30",
    "australian eastern standard time": "10:00",
    "lord howe standard time": "10:30",
    "austria": "2:00",
    "azerbaijan": "4:00",
    "bahamas": "-4:00",
    "bahrain": "3:00",
    "bangladesh": "6:00",
    "barbados": "-4:00",
    "belarus": "3:00",
    "belgium": "2:00",
    "belize": "-6:00",
    "benin": "1:00",
    "bhutan": "6:00",
    "bolivia": "-4:00",
    "bosnia and herzegovina": "2:00",
    "botswana": "2:00",
    "brunei": "8:00",
    "bulgaria": "3:00",
    "burkina faso": "0:00",
    "burundi": "2:00",
    "ivory coast": "0:00",
    "cape verde": "-1:00",
    "cambodia": "7:00",
    "cameroon": "1:00",
    "newfoundland daylight time": "-2:30",
    "atlantic daylight time": "-3:00",
    "eastern daylight time": "-4:00",
    "central daylight time": "-5:00",
    "mountain daylight time": "-6:00",
    "pacific daylight time": "-7:00",
    "chad": "1:00",
    "chile standard time": "-4:00",
    "china": "8:00",
    "columbia": "-5:00",
    "comoros": "3:00",
    "congo (congo-brazzaville)": "1:00",
    "costa rica": "-6:00",
    "croatia": "2:00",
    "cuba": "-4:00",
    "cyprus": "3:00",
    "czechia": "2:00",
    "west africa time": "1:00",
    "central africa time": "2:00",
    "denmark": "2:00",
    "djibouti": "3:00",
    "dominica": "-4:00",
    "dominican republic": "-4:00",
    "columbia time": "-5:00",
    "central standard time": "-6:00",
    "fiji": "12:00",
    "finland": "3:00",
    "at paris": "2:00",
    "tahiti time": "-10:00",
    "marquesas time": "-9:30",
    "gambier time": "-9:00",
    "easter island standard time": "-8:00",
    "atlantic standard time": "-4:00",
    "french guiana time": "-3:00",
    "pierre & miquelon daylight time": "-2:00",
    "eastern africa time": "3:00",
    "reunion time": "4:00",
    "french southern and antarctic time": "5:00",
    "new caledonia time": "11:00",
    "wallis and futuna Time": "12:00",
    "gabon": "1:00",
    "gambia": "0.00",
    "georgia": "-4:00",
    "germany": "2:00",
    "ghana": "0:00",
    "greece": "3:00",
    "grenada": "-4:00",
    "guatemala": "-6:00",
    "guinea": "0:00",
    "guinea-Bissau": "0:00",
    "guyana": "-4:00",
    "haiti": "-4:00",
    "holy See (vatican city)": "2:00",
    "honduras": "-6:00",
    "hungary": "2:00",
    "iceland": "0:00",
    "india": "5:30",
    "japan standard time": "9:00",
    "singapore standard time": "8:00",
    "western indonesian time": "7:00",
    "iran": "4:30",
    "iraq": "3:00",
    "ireland": "1:00",
    "israel": "3:00",
    "italy": "2:00",
    "jamaica": "-5:00",
    "japan": "9:00",
    "jordan": "3:00",
    "alma-ata time": "6:00",
    "azbekistan time": "5:00",
    "kenya": "3:00",
    "gilbert island time": "12:00",
    "west samoa time": "13:00",
    "kuwait": "3:00",
    "kyrgyzstan": "6:00",
    "laos": "7:00",
    "latvia": "3:00",
    "lebanon": "3:00",
    "lesotho": "2:00",
    "liberia": "0:00",
    "libya": "2:00",
    "liechtenstein": "2:00",
    "lithuania": "3:00",
    "luxembourg": "2:00",
    "madagascar": "3:00",
    "malawi": "2:00",
    "malaysia": "8:00",
    "maldives": "5:00",
    "mali": "0:00",
    "malta": "2:00",
    "marshall islands": "12:00",
    "mauritania": "0:00",
    "mauritius": "4:00",
    "tijuana UTC": "-7:00",
    "la paz UTC": "-6:00",
    "chuuk Time": "10:00",
    "pohnpei Standard Time": "11:00",
    "kosrae Time": "11:00",
    "moldovo": "2:00",
    "monaco": "2:00",
    "ulaanbaatar time": "8:00",
    "montenegro": "2:00",
    "morocco": "1:00",
    "mozambique": "2:00",
    "myanmar": "6:30",
    "namibia": "+2:00",
    "nauru": "12:00",
    "nepal": "5:45",
    "netherlands": "2:00",
    "new zealand": "12:00",
    "nicaragua": "-6:00",
    "niger": "1:00",
    "nigeria": "1:00",
    "north korea": "9:00",
    "north macedonia": "2:00",
    "norway": "2:00",
    "oman": "4:00",
    "pakistan": "5:00",
    "palau": "9:00",
    "panama": "5:00",
    "papua new guinea": "10:00",
    "paraguay": "-4:00",
    "peru": "-5:00",
    "philippines": "8:00",
    "poland": "2:00",
    "azores summer time": "0:00",
    "western european summer time": "1:00",
    "qatar": "3:00",
    "romania": "3:00",
    "eastern European Time": "2:00",
    "moscow Standard Time": "3:00",
    "yekaterinburg Time": "5:00",
    "novosibirsk Time": "7:00",
    "krasnoyarsk Time": "7:00",
    "irkutsk Time UTC": "8:00",
    "yakutsk Time UTC": "9:00",
    "vladivostok Time": "10:00",
    "magadan Time": "11:00",
    "rwanda": "2:00",
    "saint kitts and nevis": "-4:00",
    "saint lucia": "-4:00",
    "saint vincent and the grenadines": "-4:00",
    "samoa": "+13:00",
    "san marino": "2:00",
    "sao tome and principe": "0:00",
    "saudi arabia": "3:00",
    "senegal": "0:00",
    "serbia": "2:00",
    "seychelles": "4:00",
    "sierra leone": "0:00",
    "singapore": "8:00",
    "slovakia": "2:00",
    "slovenia": "2:00",
    "solomon islands": "11:00",
    "somalia": "3:00",
    "south africa": "2:00",
    "south korea": "9:00",
    "south sudan": "3:00",
    "british summer time": "1:00",
    "central european summer time": "2:00",
    "sri lanka": "5:30",
    "state of palestine": "2:00",
    "sudan": "2:00",
    "suriname": "-3:00",
    "sweden": "2:00",
    "switzerland": "2:00",
    "syria": "3:00",
    "tajikistan": "5:00",
    "tanzania": "3:00",
    "thailand": "7:00",
    "timor-leste": "9:00",
    "togo": "0:00",
    "tonga": "13:00",
    "trinidad and tobago": "-4:00",
    "tunisia": "1:00",
    "turkey": "3:00",
    "turkmenistan": "5:00",
    "tuvalu": "12:00",
    "uganda": "3:00",
    "ukraine": "3:00",
    "united arab emirates": "4:00",
    "united kingdom": "1:00",
    "mountain standard time": "-7:00",
    "alaska daylight time": "-8:00",
    "hawaii-aleutian standard time": "-10:00",
    "uruguay": "-3:00",
    "uzbekistan": "+5:00",
    "vanuatu": "11:00",
    "venezuela": "-4:00",
    "vietnam": "7:00",
    "yemen": "3:00",
    "zambia": "2:00",
    "zimbabwe": "2:00"
}


def errors(str):
    if "IsADirectoryError" in str:
        raise IsADirectoryError(
            f"User input is not on the list of countries. \nPlease use list _of_timezones or else visit:-")
    if "TypeError" in str:
        raise TypeError(
            f"User input was not in the required data type('str')")


def country_time(country):
    type_of_var = str(type(country))

    if type_of_var != "<class 'str'>":
        raise TypeError("Error")

    try:
        return country_and_time[country]
    except:
        raise errors("IsADirectoryError")


country_time("vanuatu")
