def australian_timezones():
    print("Australian Western Standard Time UTC +8:00")
    print("Australian Central Western Standard Time UTC +8:45")
    print("Australian Central Standard Time UTC +9:30")
    print("Australian Eastern Standard Time UTC +10:00")
    print("Lord Howe Standard Time UTC +10:30")


def canadian_timezones():
    print("Newfoundland DaylightTime UTC -2:30")
    print("Atlantic Daylight Time UTC -3:00")
    print("Eastern Daylight Time UTC -4:00")
    print("Central Daylight Time UTC -5:00")
    print("Mountain Daylight Time UTC -6:00")
    print("Pacific Daylight Time UTC -7:00")


def chilean_timezones():
    print("Chile Standard Time UTC -4:00")
    print("Colombia Time UTC -5:00")


def congo_timezones():
    print("West Africa Time UTC +1:00")
    print("Central Africa Time UTC +2:00")


def equador_timezones():
    print("Colombia Time UTC -5:00")
    print("Central Standard Time UTC -6:00")


def french_timezones():
    print("At Paris: (Central European Summer Time) UTC +2:00")
    print("Tahiti Time UTC -10:00")
    print("Marquesas Time UTC -9:30")
    print("Gambier Time UTC -9:00")
    print("Easter Island Standard Time UTC -8:00")
    print("Atlantic Standard Time UTC -4:00")
    print("French Guiana Time UTC -3:00")
    print("Pierre & Miquelon Daylight Time UTC -2:00")
    print("Eastern Africa Time UTC +3:00")
    print("Reunion Time UTC UTC +4:00")
    print("French Southern and Antarctic Time UTC +5:00")
    print("New Caledonia Time UTC +11:00")
    print("Wallis and Futuna Time UTC +12:00")


def indonesian_timezones():
    print("Japan Standard Time UTC +9:00")
    print("Singapore Standard Time (SST) UTC +8:00")
    print("Western Indonesian Time (WIB) UTC +7:00")


def kazakhstani_timezones():
    print("Alma-Ata Time UTC +6:00")
    print("Uzbekistan Time UTC +5:00")


def kiribatian_timezones():
    print("Gilbert Island Time UTC +12:00")
    print("West Samoa Time UTC +13:00")


def mexican_timezones():
    print("Tijuana UTC -7:00")
    print("La Paz UTC -6:00")


def micronesian_timezones():
    print("Chuuk Time UTC +10:00")
    print("Pohnpei Standard Time UTC +11:00")
    print("Kosrae Time UTC +11:00")


def mongolian_timezones():
    print("Novosibirsk Time UTC +7:00")
    print("Ulaanbaatar Time UTC +8:00")


def portugese_timezones():
    print("Azores Summer Time UTC +0:00")
    print("Western European Summer Time UTC +1:00")


def russian_timezones():
    print("Eastern European Time UTC +2:00")
    print("Moscow Standard Time UTC +3:00")
    print("Yekaterinburg Time UTC +5:00")
    print("Novosibirsk Time UTC +7:00")
    print("Krasnoyarsk Time UTC +7:00")
    print("Irkutsk Time UTC +8:00")
    print("Yakutsk Time UTC +9:00")
    print("Vladivostok Time UTC +10:00")
    print("Magadan Time Time UTC +11:00")


def spanish_timezones():
    print("British Summer Time UTC +1:00")
    print("Central European Summer Time UTC +2:00")


def usa_timezones():
    print("Eastern Daylight Time UTC -4:00")
    print("Central Daylight Time UTC -5:00")
    print("Mountain Daylight Time UTC -6:00")
    print("Pacific Daylight Time UTC -7:00")
    print("Mountain Standard Time UTC -7:00")
    print("Alaska Daylight Time UTC -8:00")
    print("Hawaii-Aleutian Standard Time UTC -10:00")


def a_countries():
    print("Afghanistan: (Afghanistan Time) UTC +4:30")
    print("Albania: (Central European Summer Time) UTC +2:00")
    print("Algeria: (Central European Time) UTC +1:00")
    print("Andorra: (Central European Summer Time) UTC +2:00")
    print("Angola: (West African Time) UTC +1:00")
    print("Antigua and Barbuda: (Atlantic Standard Time) UTC -4:00")
    print("Argentina: (Argentine Time) UTC -3:00")
    print("Armenia: (Armenian Time) UTC +4:00")
    print("Australia: has 5 time zones.")
    australian_timezones()
    print("Austria: (Central European Summer Time) UTC +2:00")
    print("Azerbaijan: (Azerbaijan Time) UTC +4:00")


def b_countries():
    print("Bahamas: (Eastern Daylight Time) UTC -4:00")
    print("Bahrain: (Arabia Standard Time) UTC +3:00")
    print("Bangladesh: (Bangladesh Standard Time) UTC +6:00")
    print("Barbados: (Atlantic Standard Time) UTC -4:00")
    print("Belarus: (Moscow Standard Time) UTC +3:00")
    print("Belgium: (Central European Summer Time) UTC +2:00")
    print("Belize: (Central Standard Time) UTC -6:00")
    print("Benin: (West Africa Time) UTC +1:00")
    print("Bhutan: (Bhutan Time) UTC +6:00")
    print("Bolivia: (Bolivia Time) UTC -4:00")
    print("Bosnia and Herzegovina: (Central European Summer Time) UTC +2:00")
    print("Botswana: (Central Africa Time) UTC +2:00")
    print("Brunei: (Brunei Darussalam Time) UTC +8:00")
    print("Bulgaria: (Eastern European Summer Time UTC) +3:00")
    print("Burkina Faso: (Greenwich Mean Time) UTC +0:00")
    print("Burundi: (Central Africa Time) UTC +2:00")


def c_countries():
    print("Ivory Coast: (Greenwich Mean Time) UTC +0:00")
    print("Cape Verde: (Cape Verde Time) UTC -1:00")
    print("Cambodia: (Indochina Time) UTC +7:00")
    print("Cameroon: (West Africa Time) UTC +1:00")
    print("Canada: has 6 time zones.")
    canadian_timezones()
    print("Chad: (West Africa Time) UTC +1:00")
    print("Chile: has 2 time zones.")
    chilean_timezones()
    print("China: (China Standard Time) UTC +8:00")
    print("Columbia: (Colombia Time) UTC -5:00")
    print("Comoros: (East Africa Time) UTC +3:00")
    print("Congo (Congo-Brazzaville): (West Africa Time) UTC +1:00")
    print("Costa Rica: (Central Standard Time) UTC -6:00")
    print("Croatia: (Central European Summer Time) UTC +2:00")
    print("Cuba: (Cuba Daylight Time) UTC -4:00")
    print("Cyprus: (Eastern European Summer Time) UTC +3:00")
    print("Czechia: (Central European Summer Time) UTC +2:00")


def d_countries():
    print("Democratic Republic of the Congo: has 2 time zones.")
    congo_timezones()
    print("Denmark: (Central European Summer Time) UTC +2:00")
    print("Djibouti: (East Africa Time) UTC +3:00")
    print("Dominica: (Atlantic Standard Time) UTC -4:00")
    print("Dominican Republic: (Atlantic Standard Time) UTC -4:00")


def e_countries():
    print("Ecuador: there are 2 time zones.")
    equador_timezones()
    print("Egypt: (Eastern European Time) UTC +2:00")
    print("El Salvador: (Central Standard Time) UTC -6:00")
    print("Equatorial Guinea: (West Africa Time) UTC +1:00")
    print("Eritrea: (East Africa Time) UTC +3:00")
    print("Estonia: (Eastern European Summer Time) UTC +3:00")
    print("Eswatini: (South Africa Standard Time) UTC +2:00")
    print("Ethiopia: (East Africa Time) UTC +3:00")


def f_countries():
    print("Fiji: (Fiji Time) UTC +12:00")
    print("Finland: (Eastern European Summer Time) UTC +3:00")
    print("France: has 12 time zones.")
    french_timezones()


def g_countries():
    print("Gabon: (West Africa Time) UTC +1:00")
    print("Gambia: (Greenwich Mean Time) UTC +0.00")
    print("Georgia: (Eastern Daylight Time) UTC -4:00")
    print("Germany: (Central European Summer Time) UTC +2:00")
    print("Ghana: (Greenwich Mean Time) UTC +0:00")
    print("Greece: (Eastern European Summer Time) UTC +3:00")
    print("Grenada: (Atlantic Standard Time) UTC -4:00")
    print("Guatemala: (Central Standard Time) UTC -6:00")
    print("Guinea: (Greenwich Mean Time) UTC +0:00")
    print("Guinea-Bissau: (Greenwich Mean Time) UTC +0:00")
    print("Guyana: (Guyana Time) UTC -4:00")


def h_countries():
    print("Haiti: (Eastern Daylight Time) UTC -4:00")
    print("Holy See (Vatican City): (Central European Summer Time) UTC +2:00")
    print("Honduras: (Central Standard Time) UTC -6:00")
    print("Hungary: (Central European Summer Time) UTC +2:00")


def i_countries():
    print("Iceland: (Greenwich Mean Time) UTC +0:00")
    print("India: (Indian Standard Time) UTC +5:30")
    print("Indonesia: has 3 time zones.")
    indonesian_timezones()
    print("Iran: (Iran Daylight Time) UTC +4:30")
    print("Iraq: (Arabia Standard Time) UTC +3:00")
    print("Ireland: (Irish Time Zone) UTC +1:00")
    print("Israel: (Israel Daylight Time) UTC +3:00")
    print("Italy: (Central European Summer Time) UTC +2:00")


def j_countries():
    print("Jamaica: (Eastern Standard Time) UTC -5:00")
    print("Japan: (Japan Standard Time) UTC +9:00")
    print("Jordan: (Eastern European Summer Time) UTC +3:00")


def k_countries():
    print("Kazakhstan: had two time zones.")
    kazakhstani_timezones()
    print("Kenya: (East Africa Time) UTC +3:00")
    print("Kiribati: has two time zones.")
    kiribatian_timezones()
    print("Kuwait: (Arabia Standard Time) UTC +3:00")
    print("Kyrgyzstan: (Kyrgyzstan Time) UTC +6:00")


def l_countries():
    print("Laos: (Indochina Time) UTC +7:00")
    print("Latvia: (Eastern European Summer Time) UTC +3:00")
    print("Lebanon: (Eastern European Summer Time) UTC +3:00")
    print("Lesotho: (South Africa Standard Time) UTC +2:00")
    print("Liberia: (Greenwich Mean Time) UTC +0:00")
    print("Libya: (Eastern European Time) UTC +2:00")
    print("Liechtenstein: (Central European Summer Time) UTC +2:00")
    print("Lithuania: (Eastern European Summer Time) UTC +3:00")
    print("Luxembourg: (Central European Summer Time) UTC +2:00")


def m_countries():
    print("Madagascar: (East Africa Time) UTC +3:00")
    print("Malawi: (Central Africa Time) UTC +2:00")
    print("Malaysia: (Malaysia Time) UTC +8:00")
    print("Maldives: (Maldives Time) UTC +5:00")
    print("Mali: (Greenwich Mean Time) UTC +0:00")
    print("Malta: (Central European Summer Time) UTC +2:00")
    print("Marshall Islands: (Marshall Islands Time) UTC +12:00")
    print("Mauritania: (Greenwich Mean Time) UTC +0:00")
    print("Mauritius: (Mauritius Time) UTC +4:00")
    print("Mexico: has two timezones.")
    mexican_timezones()
    print("Micronesia: has three time zones.")
    micronesian_timezones()
    print("Moldovo: (Eastern European Time) UTC +2:00")
    print("Monaco: (Central European Summer Time) UTC +2:00")
    print("Mongol: has two time zones.")
    mongolian_timezones()
    print("Montenegro: (Central European Summer Time) UTC +2:00")
    print("Morocco: (Western European Time) UTC +1:00")
    print("Mozambique: (Central Africa Time) UTC +2:00")
    print("Myanmar: (Myanmar Time) UTC +6:30")


def n_countries():
    print("Namibia: (Central Africa Time) UTC +2:00")
    print("Nauru: (Nauru Time) UTC +12:00")
    print("Nepal: (Nepal Time) UTC +5:45")
    print("Netherlands: (Central European Summer Time) UTC +2:00")
    print("New Zealand: (New Zealand Standard Time) UTC +12:00")
    print("Nicaragua: (Central Standard Time) UTC -6:00")
    print("Niger: (West Africa Time) UTC +1:00")
    print("Nigeria: (West Africa Time) UTC +1:00")
    print("North Korea: (Korean Standard Time) UTC +9:00")
    print("North Macedonia: (Central European Summer Time) UTC +2:00")
    print("Norway: (Central European Summer Time) UTC +2:00")


def o_countries():
    print("Oman: (Gulf Standard Time) UTC +4:00")


def p_countries():
    print("Pakistan: (Pakistan Standard Time) UTC +5:00")
    print("Palau:(Palau Time) UTC +9:00")
    print("Panama: (Eastern Standard Time) UTC -5:00")
    print("Papua New Guinea: (Papua New Guinea Time) UTC +10:00")
    print("Paraguay: (Paraguay Time) UTC -4:00")
    print("Peru: (Peru Time) UTC -5:00")
    print("Philippines: (Philippines Standard Time) UTC +8:00")
    print("Poland: (Central European Summer Time) UTC +2:00")
    print("Portugal: has two time zones.")
    portugese_timezones()


def q_countries():
    print("Qatar: (Arabia Standard Time) UTC +3:00")


def r_countries():
    print("Romania: (Eastern European Summer Time) UTC +3:00")
    print("Russia: has nine time zones.")
    russian_timezones()
    print("Rwanda: (Central Africa Time) UTC +2:00")


def s_countries():
    print("Saint Kitts and Nevis: (Atlantic Standard Time) UTC -4:00")
    print("Saint Lucia: (Atlantic Standard Time) UTC -4:00")
    print("Saint Vincent and the Grenadines: (Atlantic Standard Time) UTC -4:00")
    print("Samoa: (West Samoa Time) UTC +13:00")
    print("San Marino: (Central European Summer Time) UTC +2:00")
    print("Sao Tome and Principe: (Greenwich Mean Time) UTC +0:00")
    print("Saudi Arabia: (Arabia Standard Time) UTC +3:00")
    print("Senegal: (Greenwich Mean Time) UTC +0:00")
    print("Serbia: (Central European Summer Time) UTC +2:00")
    print("Seychelles: (Seychelles Time) UTC +4:00")
    print("Sierra Leone: (Greenwich Mean Time) UTC +0:00")
    print("Singapore: (Singapore Standard Time) UTC +8:00")
    print("Slovakia: (Central European Summer Time) UTC +2:00")
    print("Slovenia: (Central European Summer Time) UTC +2:00")
    print("Solomon Islands: (Solomon Islands Time) UTC +11:00")
    print("Somalia: (East Africa Time) UTC +3:00")
    print("South Africa: (South Africa Standard Time) UTC +2:00")
    print("South Korea: (Korean Standard Time) UTC +9:00")
    print("South Sudan: (East Africa Time) UTC +3:00")
    print("Spain: has two time zones.")
    spanish_timezones()
    print("Sri Lanka: (Indian Standard Time) UTC +5:30")
    print("State of Palestine: (Eastern European Time) UTC +2:00")
    print("Sudan: (Central Africa Time) UTC +2:00")
    print("Suriname: (Suriname Time) UTC -3:00")
    print("Sweden: (Central European Summer Time) UTC +2:00")
    print("Switzerland: (Central European Summer Time) UTC +2:00")
    print("Syria: (Eastern European Summer Time) UTC +3:00")


def t_countries():
    print("Tajikistan: (Tajikistan Time Zone) UTC +5:00")
    print("Tanzania: (East Africa Time) UTC +3:00")
    print("Thailand: (Indochina Time) UTC +7:00")
    print("Timor-Leste: (East Timor Time) UTC +9:00")
    print("Togo: (Greenwich Mean Time) UTC +0:00")
    print("Tonga: (Tonga Time) UTC +13:00")
    print("Trinidad and Tobago: (Atlantic Standard Time) UTC -4:00")
    print("Tunisia: (Central European Time) UTC +1:00")
    print("Turkey: (Turkey Time) UTC +3:00")
    print("Turkmenistan: (Turkmenistan Time) UTC +5:00")
    print("Tuvalu: (Tuvalu Time) UTC +12:00")


def u_countries():
    print("Uganda: (East Africa Time) UTC +3:00")
    print("Ukraine: (Eastern European Summer Time) UTC +3:00")
    print("United Arab Emirates: (Gulf Standard Time) UTC +4:00")
    print("United Kingdom: (British Summer Time) UTC +1:00")
    print("United States of America: has 7 time zones.")
    usa_timezones()
    print("Uruguay: (Uruguay Time) UTC -3:00")
    print("Uzbekistan: (Uzbekistan Time) UTC +5:00")


def v_countries():
    print("Vanuatu: (Vanuatu Time) UTC +11:00")
    print("Venezuela: (Venezuelan Standard Time) UTC -4:00")
    print("Vietnam: (Indochina Time) UTC +7:00")


def y_countries():
    print("Yemen: (Arabia Standard Time) UTC +3:00")


def z_countries():
    print("Zambia: (Central Africa Time) UTC +2:00")
    print("Zimbabwe: (Central Africa Time) UTC +2:00")


def list_0f_timezones():
    a_countries()
    b_countries()
    c_countries()
    d_countries()
    e_countries()
    f_countries()
    g_countries()
    h_countries()
    i_countries()
    j_countries()
    k_countries()
    l_countries()
    m_countries()
    n_countries()
    o_countries()
    p_countries()
    q_countries()
    r_countries()
    s_countries()
    t_countries()
    u_countries()
    v_countries()
    y_countries()
    z_countries()

#this is the main list of countries with info about timezones
#so if u need info on a conutries thing just use one of these